@@ -1,6 +1,5 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
-
 /**
  * functions for displaying server status variables
  *
@@ -8,14 +7,12 @@
  *
  * @package PhpMyAdmin
  */
-if (! defined('PHPMYADMIN')) {
-    exit;
-}
+use PMA\libraries\ServerStatusData;
 
 /**
  * Returns the html for the list filter
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -87,7 +84,7 @@ function PMA_getHtmlForFilter($ServerStatusData)
 /**
  * Prints the suggestion links
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -104,7 +101,7 @@ function PMA_getHtmlForLinkSuggestions($ServerStatusData)
                 $retval .= ', ';
             }
             if ('doc' == $link_name) {
-                $retval .= PMA_Util::showMySQLDocu($link_url);
+                $retval .= PMA\libraries\Util::showMySQLDocu($link_url);
             } else {
                 $retval .= '<a href="' . $link_url . '">' . $link_name . '</a>';
             }
@@ -122,7 +119,7 @@ function PMA_getHtmlForLinkSuggestions($ServerStatusData)
 /**
  * Returns a table with variables information
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
+ * @param ServerStatusData $ServerStatusData Server status data
  *
  * @return string
  */
@@ -202,9 +199,9 @@ function PMA_getHtmlForVariablesList($ServerStatusData)
 /**
  * Returns HTML for render variables list
  *
- * @param PMA_ServerStatusData $ServerStatusData Server status data
- * @param Array                $alerts           Alert Array
- * @param Array                $strShowStatus    Status Array
+ * @param ServerStatusData $ServerStatusData Server status data
+ * @param array            $alerts           Alert Array
+ * @param array            $strShowStatus    Status Array
  *
  * @return string
  */
@@ -236,8 +233,8 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
         $retval .= htmlspecialchars(str_replace('_', ' ', $name));
         // Fields containing % are calculated,
         // they can not be described in MySQL documentation
-        if (/*overload*/mb_strpos($name, '%') === false) {
-            $retval .= PMA_Util::showMySQLDocu(
+        if (mb_strpos($name, '%') === false) {
+            $retval .= PMA\libraries\Util::showMySQLDocu(
                 'server-status-variables',
                 false,
                 'statvar_' . $name
@@ -254,20 +251,24 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
             }
         }
         if (substr($name, -1) === '%') {
-            $retval .= htmlspecialchars(PMA_Util::formatNumber($value, 0, 2)) . ' %';
+            $retval .= htmlspecialchars(
+                PMA\libraries\Util::formatNumber($value, 0, 2)
+            ) . ' %';
         } elseif (strpos($name, 'Uptime') !== false) {
             $retval .= htmlspecialchars(
-                PMA_Util::timespanFormat($value)
+                PMA\libraries\Util::timespanFormat($value)
             );
         } elseif (is_numeric($value) && $value > 1000) {
             $retval .= '<abbr title="'
                 // makes available the raw value as a title
-                . htmlspecialchars(PMA_Util::formatNumber($value, 0))
+                . htmlspecialchars(PMA\libraries\Util::formatNumber($value, 0))
                 . '">'
-                . htmlspecialchars(PMA_Util::formatNumber($value, 3, 1))
+                . htmlspecialchars(PMA\libraries\Util::formatNumber($value, 3, 1))
                 . '</abbr>';
         } elseif (is_numeric($value)) {
-            $retval .= htmlspecialchars(PMA_Util::formatNumber($value, 3, 1));
+            $retval .= htmlspecialchars(
+                PMA\libraries\Util::formatNumber($value, 3, 1)
+            );
         } else {
             $retval .= htmlspecialchars($value);
         }
@@ -298,7 +299,7 @@ function PMA_getHtmlForRenderVariables($ServerStatusData, $alerts, $strShowStatu
         if (isset($ServerStatusData->links[$name])) {
             foreach ($ServerStatusData->links[$name] as $link_name => $link_url) {
                 if ('doc' == $link_name) {
-                    $retval .= PMA_Util::showMySQLDocu($link_url);
+                    $retval .= PMA\libraries\Util::showMySQLDocu($link_url);
                 } else {
                     $retval .= ' <a href="' . $link_url . '">' . $link_name . '</a>';
                 }
