@@ -243,9 +243,9 @@ class Expression extends Component
                         if (!empty($options['breakOnAlias'])) {
                             break;
                         }
-                        if (!empty($ret->alias)) {
+                        if ($alias) {
                             $parser->error(
-                                __('An alias was previously found.'),
+                                __('An alias was expected.'),
                                 $token
                             );
                             break;
@@ -254,6 +254,9 @@ class Expression extends Component
                         continue;
                     }
                     $isExpr = true;
+                } elseif ($brackets === 0 && count($ret->expr) > 0) {
+                    /* End of expression */
+                    break;
                 }
             }
 
