@@ -29,7 +29,9 @@ textarea {
 body {
 <?php if (! empty($GLOBALS['cfg']['FontFamily'])) { ?>
     font-family:        <?php echo $GLOBALS['cfg']['FontFamily']; ?>;
-<?php } ?>
+    <?php
+}
+?>
     padding:            0;
     margin: 0;
     margin-<?php echo $left; ?>: 240px;
@@ -46,10 +48,12 @@ body#loginform {
 }
 
 <?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) { ?>
-textarea, tt, pre, code {
+    textarea, tt, pre, code {
     font-family:        <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
+    }
+    <?php
 }
-<?php } ?>
+?>
 h1 {
     font-size:          140%;
     font-weight:        bold;
@@ -116,11 +120,6 @@ form {
 
 textarea {
     overflow:           visible;
-    height:             <?php echo ceil($GLOBALS['cfg']['TextareaRows'] * 1.2); ?>em;
-}
-
-textarea.char {
-    height:             <?php echo ceil($GLOBALS['cfg']['CharTextareaRows'] * 1.2); ?>em;
 }
 
 fieldset {
@@ -177,6 +176,10 @@ button {
     margin-<?php echo $right; ?>: 1em;
 }
 
+.floatright {
+    float: <?php echo $right; ?>;
+}
+
 table.nospacing {
     border-spacing: 0;
 }
@@ -195,6 +198,7 @@ th.center, td.center {
 
 th.right, td.right {
     text-align: right;
+    padding-right: 1em;
 }
 
 tr.vtop, th.vtop, td.vtop {
@@ -243,23 +247,6 @@ fieldset .formelement {
     white-space:        nowrap;
 }
 
-@media all and (min-width: 1600px) {
-    fieldset .formelement {
-        clear: none;
-    }
-    #relationalTable td:first-child + td {
-        width: 25%;
-    }
-    #relationalTable td:first-child + td select {
-        width: 32%;
-        margin-right: 1%;
-    }
-    #relationalTable {
-        width: 100%;
-    }
-
-}
-
 /* revert for Gecko */
 fieldset div[class=formelement] {
     white-space:        normal;
@@ -290,34 +277,30 @@ table tr.even {
     text-align:         <?php echo $left; ?>;
 }
 
-<?php if ($GLOBALS['cfg']['BrowseMarkerEnable']) { ?>
 /* marked table rows */
-td.marked,
-table tr.marked td,
-table tr.marked th,
-table tr.marked {
+td.marked:not(.nomarker),
+table tr.marked:not(.nomarker) td,
+table tr.marked:not(.nomarker) th,
+table tr.marked:not(.nomarker) {
     background:   <?php echo $GLOBALS['cfg']['BrowseMarkerBackground']; ?>;
     color:   <?php echo $GLOBALS['cfg']['BrowseMarkerColor']; ?>;
 }
-<?php } ?>
 
-<?php if ($GLOBALS['cfg']['BrowsePointerEnable']) { ?>
 /* hovered items */
-.odd:hover,
-.even:hover,
-.hover {
+.odd:not(.nopointer):hover,
+.even:not(.nopointer):hover,
+.hover:not(.nopointer) {
     background: <?php echo $GLOBALS['cfg']['BrowsePointerBackground']; ?>;
     color: <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
 }
 
 /* hovered table rows */
-table tr.odd:hover th,
-table tr.even:hover th,
-table tr.hover th {
+table tr.odd:not(.nopointer):hover th,
+table tr.even:not(.nopointer):hover th,
+table tr.hover:not(.nopointer) th {
     background:   <?php echo $GLOBALS['cfg']['BrowsePointerBackground']; ?>;
     color:   <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
 }
-<?php } ?>
 
 /**
  * marks table rows/cells if the db field is in a where condition
@@ -350,10 +333,12 @@ table [class=value] {
 
 
 <?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) { ?>
-.value {
-    font-family:        <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
+    .value {
+        font-family:        <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
+    }
+    <?php
 }
-<?php } ?>
+?>
 .attention {
     color:              red;
     font-weight:        bold;
@@ -414,7 +399,7 @@ td .icon {
 }
 
 /* message boxes: error, confirmation */
-#pma_errors, #pma_demo {
+#pma_errors, #pma_demo, #pma_footer {
     padding: 0 0.5em;
 }
 
@@ -433,13 +418,17 @@ div.error {
     margin:             0.3em 0 0 0;
     border:             2px solid;
     background-repeat:  no-repeat;
-        <?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
-    background-position: 10px 50%;
-    padding:            0.1em 0.1em 0.1em 36px;
-        <?php } else { ?>
-    background-position: 99% 50%;
-    padding:            0.1em 46px 0.1em 0.1em;
-        <?php } ?>
+    <?php
+    if ($GLOBALS['text_dir'] === 'ltr') { ?>
+        background-position: 10px 50%;
+        padding:            0.1em 0.1em 0.1em 36px;
+    <?php
+    } else { ?>
+        background-position: 99% 50%;
+        padding:            0.1em 46px 0.1em 0.1em;
+        <?php
+    }
+?>
 }
 
 .success {
@@ -491,13 +480,17 @@ fieldset.confirmation legend {
     font-weight:        bold;
     background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_really.png');?>);
     background-repeat:  no-repeat;
-        <?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
-    background-position: 5px 50%;
-    padding:            0.2em 0.2em 0.2em 25px;
-        <?php } else { ?>
-    background-position: 97% 50%;
-    padding:            0.2em 25px 0.2em 0.2em;
-        <?php } ?>
+    <?php
+    if ($GLOBALS['text_dir'] === 'ltr') { ?>
+        background-position: 5px 50%;
+        padding:            0.2em 0.2em 0.2em 25px;
+        <?php
+    } else { ?>
+        background-position: 97% 50%;
+        padding:            0.2em 25px 0.2em 0.2em;
+        <?php
+    }
+?>
 }
 /* end messageboxes */
 
@@ -739,6 +732,9 @@ div#dataDisplay input, div#dataDisplay select {
 div#dataDisplay th {
     line-height: 2em;
 }
+table#tableFieldsId {
+    width: 100%;
+}
 
 /* Calendar */
 table.calendar {
@@ -812,15 +808,32 @@ div#tablestatistics table {
     white-space:        nowrap;
 }
 
-#goto_pagetop {
+#page_nav_icons {
     position: fixed;
-    padding: .1em .3em;
     top: 0;
     <?php echo $right; ?>: 0;
-    z-index: 900;
+    z-index: 99;
+    padding: .1em 0;
+}
+
+#goto_pagetop, #lock_page_icon, #page_settings_icon {
+    padding: .3em;
     background: white;
 }
 
+#page_settings_icon {
+    cursor: pointer;
+    display: none;
+}
+
+#page_settings_modal {
+    display: none;
+}
+
+#pma_navigation_settings {
+    display: none;
+}
+
 #span_table_comment {
     font-weight: bold;
     font-style: italic;
@@ -922,7 +935,7 @@ div#tablestatistics table {
     float: <?php echo $left; ?>;
 }
 
-#fieldset_user_global_rights legend input {
+#fieldset_user_global_rights>legend input {
     margin-<?php echo $left; ?>: 2em;
 }
 /* end user privileges */
@@ -941,12 +954,6 @@ h3#serverstatusqueries span {
     display:inline;
 }
 
-img.sortableIcon {
-    float:right;
-    background-repeat:no-repeat;
-    margin:0;
-}
-
 .buttonlinks {
     float: <?php echo $right; ?>;
     white-space: nowrap;
@@ -1023,15 +1030,29 @@ div#chartVariableSettings {
     margin-left:10px;
 }
 
-table#chartGrid div.monitorChart {
-    background: #EBEBEB;
-    width: 400px;
-    height: 300px;
+table#chartGrid td {
+    padding: 3px;
+    margin: 0;
 }
 
-div#serverstatus div.tabLinks {
-    float:<?php echo $left; ?>;
-    padding-bottom: 10px;
+table#chartGrid div.monitorChart {
+    background: #EBEBEB;
+    overflow: hidden;
+    border: none;
+}
+
+div.tabLinks {
+    margin-left: 0.3em;
+    float: <?php echo $left; ?>;
+    padding: 5px 0;
+}
+
+div.tabLinks a, div.tabLinks label {
+    margin-right: 7px;
+}
+
+div.tabLinks .icon {
+    margin: -0.2em 0.3em 0 0;
 }
 
 .popupContent {
@@ -1064,9 +1085,10 @@ div#logTable table {
 
 /* server variables */
 #serverVariables {
-    min-width: 30em;
+    table-layout: fixed;
+    width: 100%;
 }
-#serverVariables .var-row > div {
+#serverVariables .var-row > tr {
     white-space: nowrap;
     overflow: hidden;
     text-overflow: ellipsis;
@@ -1078,15 +1100,17 @@ div#logTable table {
     color:              <?php echo $GLOBALS['cfg']['ThColor']; ?>;
     background:         <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
 }
-#serverVariables .var-header .var-value {
+#serverVariables .var-header {
     text-align: <?php echo $left; ?>;
 }
 #serverVariables .var-row {
     padding: 0.5em;
     min-height: 18px;
 }
+#serverVariables .var-action {
+    width: 120px;
+}
 #serverVariables .var-name {
-    width: 45%;
     float: <?php echo $left; ?>;
     font-weight: bold;
 }
@@ -1131,25 +1155,6 @@ div#logTable table {
 }
 /* end server variables */
 
-/* querywindow */
-body#bodyquerywindow {
-    margin: 0;
-    padding: 0;
-    background-image: none;
-    background-color: #F5F5F5;
-}
-
-div#querywindowcontainer {
-    margin: 0;
-    padding: 0;
-    width: 100%;
-}
-
-div#querywindowcontainer fieldset {
-    margin-top: 0;
-}
-/* end querywindow */
-
 /* profiling */
 
 div#profilingchart {
@@ -1163,31 +1168,15 @@ div#profilingchart {
     left: 11px;
     bottom:24px;
 }
-
-#profilesummarytable th.header, #profiletable th.header{
-    cursor: pointer;
-}
-
-#profilesummarytable th.header .sorticon, #profiletable th.header .sorticon{
-    width: 16px;
-    height: 16px;
-    background-repeat: no-repeat;
-    background-position: right center;
-    display: inline-block;
-    vertical-align: middle;
-    float: right;
-}
-
-#profilesummarytable th.headerSortUp .sorticon, #profiletable th.headerSortUp .sorticon{
-    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_desc.png');?>);
-}
-
-#profilesummarytable th.headerSortDown .sorticon, #profiletable th.headerSortDown .sorticon{
-    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
-}
-
 /* end profiling */
 
+/* table charting */
+.chartOption {
+    float: <?php echo $left; ?>;
+    margin-<?php echo $right;?>: 40px;
+}
+/* end table charting */
+
 /* querybox */
 
 div#sqlquerycontainer {
@@ -1240,7 +1229,7 @@ div#queryboxcontainer div#bookmarkoptions {
 }
 
 #maincontainer li {
-    margin:  0.2em 0em;
+    margin:  0.2em 0;
 }
 
 #full_name_layer {
@@ -1269,10 +1258,6 @@ li.no_bullets {
     margin: .5em .5em 0 .5em;
 }
 
-#bodyquerywindow {
-    background:         <?php echo $GLOBALS['cfg']['NaviBackground']; ?>;
-}
-
 #bodythemes {
     width: 500px;
     margin: auto;
@@ -1370,9 +1355,10 @@ div.sqlvalidate {
     margin-bottom:      0;
     max-height:         10em;
     overflow:           auto;
+    direction:          ltr;
 }
 
-#result_query div.sqlOuter,
+.result_query div.sqlOuter,
 div.sqlvalidate  {
     border:             <?php echo $GLOBALS['cfg']['MainColor']; ?> solid 1px;
     border-top:         0;
@@ -1493,6 +1479,7 @@ input[type=text].invalid_value,
 input[type=password].invalid_value,
 input[type=number].invalid_value,
 input[type=date].invalid_value,
+select.invalid_value,
 .invalid_value {
     background: #FFCCCC;
 }
@@ -1529,6 +1516,30 @@ input[type=date].invalid_value,
   * Export and Import styles
   */
 
+.export_table_list_container {
+    display: inline-block;
+    max-height: 20em;
+    overflow-y: scroll;
+}
+
+.export_table_select th {
+    text-align: center;
+    vertical-align: middle;
+}
+
+.export_table_select .all {
+    font-weight: bold;
+    border-bottom: 1px solid black;
+}
+
+.export_structure, .export_data {
+    text-align: center;
+}
+
+.export_table_name {
+    vertical-align: middle;
+}
+
 .exportoptions h3, .importoptions h3 {
     border-bottom: 1px #999999 solid;
     font-size: 110%;
@@ -1662,9 +1673,6 @@ input#input_import_file {
 #addColumns input[type="submit"] {
     margin-<?php echo $left; ?>: 1em;
 }
-.margin#change_column_dialog {
-    margin: 0 .5em;
-}
 
 /**
  * Indexes
@@ -1705,7 +1713,8 @@ table#index_columns {
 }
 
 table#index_columns select {
-    width: 100%;
+    width: 85%;
+    float: right;
 }
 
 #move_columns_dialog div {
@@ -1952,6 +1961,7 @@ fieldset .disabled-field td {
 
 #prefs_autoload {
     margin-bottom: .5em;
+    margin-left: .5em;
 }
 
 #placeholder .button {
@@ -1990,6 +2000,10 @@ fieldset .disabled-field td {
 .toggleButton .container {
     position: absolute;
 }
+.toggleButton .container td {
+    background-image: none;
+    background: none;
+}
 .toggleButton .toggleOn {
     color: #fff;
     padding: 0 1em;
@@ -2016,6 +2030,17 @@ fieldset .disabled-field td {
     padding: 0.5em;
 }
 
+#table_name_col_no_outer {
+    margin-top: 30px;
+}
+
+#table_name_col_no {
+    position: fixed;
+    top: 44px;
+    width: 100%;
+    background: <?php echo $GLOBALS['cfg']['MainBackground']; ?>;
+}
+
 #table_columns input[type="text"],
 #table_columns input[type="password"],
 #table_columns input[type="number"],
@@ -2031,7 +2056,7 @@ fieldset .disabled-field td {
 #placeholder {
     position: relative;
     border: 1px solid #aaa;
-    float: right;
+    float: <?php echo $right; ?>;
     overflow: hidden;
 }
 
@@ -2100,6 +2125,10 @@ fieldset .disabled-field td {
     overflow: hidden;
 }
 
+.pma_table tbody td span code span {
+    display: inline;
+}
+
 .modal-copy input {
     display: block;
     width: 100%;
@@ -2298,11 +2327,6 @@ fieldset .disabled-field td {
     height: 10em;
 }
 
-.cEdit .edit_area_right {
-    position: absolute;
-    right: 0;
-}
-
 .cEdit .goto_link {
     background: #EEE;
     color: #555;
@@ -2316,10 +2340,14 @@ fieldset .disabled-field td {
 
 /* css for timepicker */
 .ui-timepicker-div .ui-widget-header { margin-bottom: 8px; }
-.ui-timepicker-div dl { text-align: left; }
-.ui-timepicker-div dl dt { height: 25px; }
-.ui-timepicker-div dl dd { margin: -25px 0 10px 85px; }
+.ui-timepicker-div dl { text-align: <?php echo $left; ?>; }
+.ui-timepicker-div dl dt { height: 25px; margin-bottom: -25px; }
+.ui-timepicker-div dl dd { margin: 0 10px 10px 85px; }
 .ui-timepicker-div td { font-size: 90%; }
+.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; }
+.ui-timepicker-rtl { direction: rtl; }
+.ui-timepicker-rtl dl { text-align: right; }
+.ui-timepicker-rtl dl dd { margin: 0 65px 10px 10px; }
 
 input.btn {
     color: #333;
@@ -2381,45 +2409,39 @@ according to css rules*/
 
 
 .jqplot-xaxis-tick {
-    top: 0px;
+    top: 0;
     /* initial position untill tick is drawn in proper place */
     left: 15px;
-/*    padding-top: 10px;*/
     vertical-align: top;
 }
 
 .jqplot-x2axis-tick {
-    bottom: 0px;
+    bottom: 0;
     /* initial position untill tick is drawn in proper place */
     left: 15px;
-/*    padding-bottom: 10px;*/
     vertical-align: bottom;
 }
 
 .jqplot-yaxis-tick {
-    right: 0px;
+    right: 0;
     /* initial position untill tick is drawn in proper place */
     top: 15px;
-/*    padding-right: 10px;*/
     text-align: right;
 }
 
 .jqplot-yaxis-tick.jqplot-breakTick {
     right: -20px;
-    margin-right: 0px;
+    margin-right: 0;
     padding:1px 5px 1px 5px;
-/*  background-color: white;*/
     z-index: 2;
     font-size: 1.5em;
 }
 
 .jqplot-y2axis-tick, .jqplot-y3axis-tick, .jqplot-y4axis-tick, .jqplot-y5axis-tick,
 .jqplot-y6axis-tick, .jqplot-y7axis-tick, .jqplot-y8axis-tick, .jqplot-y9axis-tick {
-    left: 0px;
-    /* initial position untill tick is drawn in proper place */
+    left: 0;
+    /* initial position until tick is drawn in proper place */
     top: 15px;
-/*    padding-left: 10px;*/
-/*    padding-right: 15px;*/
     text-align: left;
 }
 
@@ -2519,8 +2541,8 @@ div.jqplot-table-legend-swatch-outline {
 }
 
 div.jqplot-table-legend-swatch {
-    width:0px;
-    height:0px;
+    width:0;
+    height:0;
     border-top-width: 5px;
     border-bottom-width: 5px;
     border-left-width: 6px;
@@ -2532,8 +2554,8 @@ div.jqplot-table-legend-swatch {
 }
 
 .jqplot-title {
-    top: 0px;
-    left: 0px;
+    top: 0;
+    left: 0;
     padding-bottom: 0.5em;
     font-size: 1.2em;
 }
@@ -2604,7 +2626,7 @@ div.jqplot-noData-container {
     background-color: rgba(96%, 96%, 96%, 0.3);
 }
 
-#relationalTable select {
+.relationalTable select {
     width: 125px;
     margin-right: 5px;
 }
@@ -2631,6 +2653,621 @@ div#page_content form#db_search_form.ajax fieldset {
     margin-top: -0.3em;
 }
 
-div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div#result_query {
+div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div.result_query {
     margin-top: 1em;
 }
+
+table.show_create {
+    margin-top: 1em;
+}
+
+table.show_create td {
+    border-right: 1px solid #bbb;
+}
+
+#alias_modal table th {
+    vertical-align: middle;
+    padding-left: 1em;
+}
+
+#alias_modal label.col-2 {
+    min-width: 20%;
+    display: inline-block;
+}
+
+#alias_modal select {
+    width: 25%;
+    margin-right: 2em;
+}
+
+#alias_modal label {
+    font-weight: bold;
+}
+
+.ui-dialog {
+    position: fixed;
+}
+
+.small_font {
+    font-size: smaller;
+}
+
+/* Console styles */
+#pma_console_container {
+    width: 100%;
+    position: fixed;
+    bottom: 0;
+    <?php echo $left; ?>: 0;
+    z-index: 100;
+}
+#pma_console {
+    position: relative;
+    margin-<?php echo $left; ?>: 240px;
+    z-index: 100;
+}
+#pma_console .templates {
+    display: none;
+}
+#pma_console .mid_text,
+#pma_console .toolbar span {
+    vertical-align: middle;
+}
+#pma_console .toolbar {
+    position: relative;
+    background: #ccc;
+    border-top: solid 1px #aaa;
+    cursor: n-resize;
+}
+#pma_console .toolbar.collapsed:not(:hover) {
+    display: inline-block;
+    border-top-<?php echo $right; ?>-radius: 3px;
+    border-<?php echo $right; ?>: solid 1px #aaa;
+}
+#pma_console .toolbar.collapsed {
+    cursor: default;
+}
+#pma_console .toolbar.collapsed>.button {
+    display: none;
+}
+#pma_console .message span.text,
+#pma_console .message span.action,
+#pma_console .toolbar .button,
+#pma_console .toolbar .text,
+#pma_console .switch_button {
+    padding: 0 3px;
+    display: inline-block;
+}
+#pma_console .message span.action,
+#pma_console .toolbar .button,
+#pma_console .switch_button {
+    cursor: pointer;
+}
+#pma_console .message span.action:hover,
+#pma_console .toolbar .button:hover,
+#pma_console .switch_button:hover,
+#pma_console .toolbar .button.active {
+    background: #ddd;
+}
+#pma_console .toolbar .text {
+    font-weight: bold;
+}
+#pma_console .toolbar .button,
+#pma_console .toolbar .text {
+    margin-<?php echo $right; ?>: .4em;
+}
+#pma_console .toolbar .button,
+#pma_console .toolbar .text {
+    float: <?php echo $right; ?>;
+}
+#pma_console .content {
+    overflow-x: hidden;
+    overflow-y: auto;
+    margin-bottom: -65px;
+    border-top: solid 1px #aaa;
+    background: #fff;
+    padding-top: .4em;
+}
+#pma_console .content.console_dark_theme {
+    background: #000;
+    color: #fff;
+}
+#pma_console .content.console_dark_theme .CodeMirror-wrap {
+    background: #000;
+    color: #fff;
+}
+#pma_console .content.console_dark_theme .action_content {
+    color: #000;
+}
+#pma_console .content.console_dark_theme .message {
+    border-color: #373B41;
+}
+#pma_console .content.console_dark_theme .CodeMirror-cursor {
+    border-color: #fff;
+}
+#pma_console .content.console_dark_theme .cm-keyword {
+    color: #de935f;
+}
+#pma_console .message,
+#pma_console .query_input {
+    position: relative;
+    font-family: Monaco, Consolas, monospace;
+    cursor: text;
+    margin: 0 10px .2em 1.4em;
+}
+#pma_console .message {
+    border-bottom: solid 1px #ccc;
+    padding-bottom: .2em;
+}
+#pma_console .message.expanded>.action_content {
+    position: relative;
+}
+#pma_console .message:before,
+#pma_console .query_input:before {
+    left: -0.7em;
+    position: absolute;
+    content: ">";
+}
+#pma_console .query_input:before {
+    top: -2px;
+}
+#pma_console .query_input textarea {
+    width: 100%;
+    height: 4em;
+    resize: vertical;
+}
+#pma_console .message:hover:before {
+    color: #7cf;
+    font-weight: bold;
+}
+#pma_console .message.expanded:before {
+    content: "]";
+}
+#pma_console .message.welcome:before {
+    display: none;
+}
+#pma_console .message.failed:before,
+#pma_console .message.failed.expanded:before,
+#pma_console .message.failed:hover:before {
+    content: "=";
+    color: #944;
+}
+#pma_console .message.pending:before {
+    opacity: .3;
+}
+#pma_console .message.collapsed>.query {
+    white-space: nowrap;
+    text-overflow: ellipsis;
+    overflow: hidden;
+}
+#pma_console .message.expanded>.query {
+    display: block;
+    white-space: pre;
+    word-wrap: break-word;
+}
+#pma_console .message .text.targetdb,
+#pma_console .message.collapsed .action.collapse,
+#pma_console .message.expanded .action.expand,
+#pma_console .message .action.requery,
+#pma_console .message .action.profiling,
+#pma_console .message .action.explain,
+#pma_console .message .action.bookmark {
+    display: none;
+}
+#pma_console .message.select .action.profiling,
+#pma_console .message.select .action.explain,
+#pma_console .message.history .text.targetdb,
+#pma_console .message.successed .text.targetdb,
+#pma_console .message.history .action.requery,
+#pma_console .message.history .action.bookmark,
+#pma_console .message.bookmark .action.requery,
+#pma_console .message.bookmark .action.bookmark,
+#pma_console .message.successed .action.requery,
+#pma_console .message.successed .action.bookmark {
+    display: inline-block;
+}
+#pma_console .message .action_content {
+    position: absolute;
+    bottom: 100%;
+    background: #ccc;
+    border: solid 1px #aaa;
+    border-top-<?php echo $left; ?>-radius: 3px;
+}
+html.ie8 #pma_console .message .action_content {
+    position: relative!important;
+}
+#pma_console .message.bookmark .text.targetdb,
+#pma_console .message .text.query_time {
+    margin: 0;
+    display: inline-block;
+}
+#pma_console .message.failed .text.query_time,
+#pma_console .message .text.failed {
+    display: none;
+}
+#pma_console .message.failed .text.failed {
+    display: inline-block;
+}
+#pma_console .message .text {
+    background: #fff;
+}
+#pma_console .message.collapsed>.action_content {
+    display: none;
+}
+#pma_console .message.collapsed:hover>.action_content {
+    display: block;
+}
+#pma_console .message .bookmark_label {
+    padding: 0 4px;
+    top: 0;
+    background: #369;
+    color: #fff;
+    border-radius: 3px;
+}
+#pma_console .message .bookmark_label.shared {
+    background: #396;
+}
+#pma_console .message.expanded .bookmark_label {
+    border-top-left-radius: 0;
+    border-top-right-radius: 0;
+}
+#pma_console .query_input {
+    position: relative;
+}
+#pma_console .mid_layer {
+    height: 100%;
+    width: 100%;
+    position: absolute;
+    top: 0;
+    /* For support IE8, this layer doesn't use filter:opacity or opacity,
+    js code will fade this layer opacity to 0.18(using animation) */
+    background: #666;
+    display: none;
+    cursor: pointer;
+    z-index: 200;
+}
+#pma_console .card {
+    position: absolute;
+    width: 94%;
+    height: 100%;
+    min-height: 48px;
+    <?php echo $left; ?>: 100%;
+    top: 0;
+    border-<?php echo $left; ?>: solid 1px #999;
+    z-index: 300;
+    transition: <?php echo $left; ?> 0.2s;
+    -ms-transition: <?php echo $left; ?> 0.2s;
+    -webkit-transition: <?php echo $left; ?> 0.2s;
+    -moz-transition: <?php echo $left; ?> 0.2s;
+}
+#pma_console .card.show {
+    <?php echo $left; ?>: 6%;
+    box-shadow: -2px 1px 4px -1px #999;
+}
+
+html.ie7 #pma_console .query_input {
+    display: none;
+}
+
+#pma_bookmarks .content.add_bookmark,
+#pma_console_options .content {
+    padding: 4px 6px;
+}
+#pma_bookmarks .content.add_bookmark .options {
+    margin-<?php echo $left; ?>: 1.4em;
+    padding-bottom: .4em;
+    margin-bottom: .4em;
+    border-bottom: solid 1px #ccc;
+}
+#pma_bookmarks .content.add_bookmark .options button {
+    margin: 0 7px;
+    vertical-align: bottom;
+}
+#pma_bookmarks .content.add_bookmark input[type=text] {
+    margin: 0;
+    padding: 2px 4px;
+}
+#pma_console .button.hide,
+#pma_console .message span.text.hide {
+    display: none;
+}
+#debug_console.grouped .ungroup_queries,
+#debug_console.ungrouped .group_queries {
+    display: inline-block;
+}
+#debug_console.ungrouped .ungroup_queries,
+#debug_console.ungrouped .sort_count,
+#debug_console.grouped .group_queries {
+    display: none;
+}
+#debug_console .count {
+    margin-right: 8px;
+}
+#debug_console .show_trace .trace,
+#debug_console .show_args .args {
+    display: block;
+}
+#debug_console .hide_trace .trace,
+#debug_console .hide_args .args,
+#debug_console .show_trace .action.dbg_show_trace,
+#debug_console .hide_trace .action.dbg_hide_trace,
+#debug_console .traceStep.hide_args .action.dbg_hide_args,
+#debug_console .traceStep.show_args .action.dbg_show_args {
+    display: none;
+}
+
+#debug_console .traceStep:after,
+#debug_console .trace.welcome:after,
+#debug_console .debug>.welcome:after {
+    content: "";
+    display: table;
+    clear: both;
+}
+#debug_console .debug_summary {
+    float: left;
+}
+#debug_console .trace.welcome .time {
+    float: right;
+}
+#debug_console .traceStep .file,
+#debug_console .script_name {
+    float: right;
+}
+#debug_console .traceStep .args pre {
+    margin: 0;
+}
+
+/* Code mirror console style*/
+
+.cm-s-pma .CodeMirror-code pre,
+.cm-s-pma .CodeMirror-code {
+    font-family: Monaco, Consolas, monospace;
+}
+.cm-s-pma .CodeMirror-measure>pre,
+.cm-s-pma .CodeMirror-code>pre,
+.cm-s-pma .CodeMirror-lines {
+    padding: 0;
+}
+.cm-s-pma.CodeMirror {
+    resize: none;
+    height: auto;
+    width: 100%;
+    min-height: initial;
+    max-height: initial;
+}
+.firefox .cm-s-pma.CodeMirror {
+    font-size: 120%;
+}
+.cm-s-pma .CodeMirror-scroll {
+    cursor: text;
+}
+
+/* PMA drop-improt style */
+
+.pma_drop_handler {
+    display: none;
+    position: fixed;
+    top: 0;
+    left: 0;
+    width: 100%;
+    background: rgba(0, 0, 0, 0.6);
+    height: 100%;
+    z-index: 999;
+    color: white;
+    font-size: 30pt;
+    text-align: center;
+    padding-top: 20%;
+}
+
+.pma_sql_import_status {
+    display: none;
+    position: fixed;
+    bottom: 0;
+    right: 25px;
+    width: 400px;
+    border: 1px solid #999;
+    background: #f3f3f3;
+    -moz-border-radius: 4px;
+    -webkit-border-radius: 4px;
+    border-radius: 4px;
+    -moz-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>2px 2px 5px #ccc;
+    -webkit-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>2px 2px 5px #ccc;
+    box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>2px 2px 5px #ccc;
+}
+
+.pma_sql_import_status h2,
+.pma_drop_result h2 {
+    background-color: #bbb;
+    padding: .1em .3em;
+    margin-top: 0;
+    margin-bottom: 0;
+    color: #fff;
+    font-size: 1.6em;
+    font-weight: normal;
+    text-shadow: 0 1px 0 #777;
+    -moz-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 15px #999 inset;
+    -webkit-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 15px #999 inset;
+    box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 15px #999 inset;
+}
+
+.pma_sql_import_status div {
+    height: 270px;
+    overflow-y:auto;
+    overflow-x:hidden;
+    list-style-type: none;
+}
+
+.pma_sql_import_status div li {
+    padding: 8px 10px;
+    border-bottom: 1px solid #bbb;
+    color: rgb(148, 14, 14);
+    background: white;
+}
+
+.pma_sql_import_status div li .filesize {
+    float: right;
+}
+
+.pma_sql_import_status h2 .minimize {
+    float: right;
+    margin-right: 5px;
+    padding: 0 10px;
+}
+
+.pma_sql_import_status h2 .close {
+    float: right;
+    margin-right: 5px;
+    padding: 0 10px;
+    display: none;
+}
+
+.pma_sql_import_status h2 .minimize:hover,
+.pma_sql_import_status h2 .close:hover,
+.pma_drop_result h2 .close:hover {
+    background: rgba(155, 149, 149, 0.78);
+    cursor: pointer;
+}
+
+.pma_drop_file_status {
+    color: #235a81;
+}
+
+.pma_drop_file_status span.underline:hover {
+    cursor: pointer;
+    text-decoration: underline;
+}
+
+.pma_drop_result {
+    position: fixed;
+    top: 10%;
+    left: 20%;
+    width: 60%;
+    background: white;
+    min-height: 300px;
+    z-index: 800;
+    -webkit-box-shadow: 0 0 15px #999;
+    border-radius: 10px;
+    cursor: move;
+}
+
+.pma_drop_result h2 .close {
+    float: right;
+    margin-right: 5px;
+    padding: 0 10px;
+}
+
+#composite_index_list {
+    list-style-type: none;
+    list-style-position: inside;
+}
+
+span.drag_icon {
+    display: inline-block;
+    background-image: url('<?php echo $_SESSION['PMA_Theme']->getImgPath('s_sortable.png');?>');
+    background-position: center center;
+    background-repeat: no-repeat;
+    width: 1em;
+    height: 3em;
+    cursor: move;
+}
+
+.topmargin {
+    margin-top: 1em;
+}
+
+/* styles for sortable tables created with tablesorter jquery plugin */
+th.header {
+    cursor: pointer;
+    color: #0000FF;
+}
+
+th.header:hover {
+    text-decoration: underline;
+}
+
+th.header .sorticon {
+    width: 16px;
+    height: 16px;
+    background-repeat: no-repeat;
+    background-position: right center;
+    display: inline-table;
+    vertical-align: middle;
+    float: right;
+}
+
+th.headerSortUp .sorticon, th.headerSortDown:hover .sorticon {
+    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_desc.png');?>);
+}
+
+th.headerSortDown .sorticon, th.headerSortUp:hover .sorticon {
+    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
+}
+/* end of styles of sortable tables */
+
+/* styles for jQuery-ui to support rtl languages */
+body .ui-dialog .ui-dialog-titlebar-close {
+    <?php echo $right; ?>: .3em;
+    <?php echo $left; ?>: initial;
+}
+
+body .ui-dialog .ui-dialog-title {
+    float: <?php echo $left; ?>;
+}
+
+body .ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
+    float: <?php echo $right; ?>;
+}
+/* end of styles for jQuery-ui to support rtl languages */
+
+/* Override some jQuery-ui styling to have square corners */
+body .ui-corner-all,
+body .ui-corner-top,
+body .ui-corner-left,
+body .ui-corner-tl {
+    border-top-left-radius: 0;
+}
+body .ui-corner-all,
+body .ui-corner-top,
+body .ui-corner-right,
+body .ui-corner-tr {
+    border-top-right-radius: 0;
+}
+body .ui-corner-all,
+body .ui-corner-bottom,
+body .ui-corner-left,
+body .ui-corner-bl {
+    border-bottom-left-radius: 0;
+}
+body .ui-corner-all,
+body .ui-corner-bottom,
+body .ui-corner-right,
+body .ui-corner-br {
+    border-bottom-right-radius: 0;
+}
+/* Override  jQuery-ui styling for ui-dialog */
+body .ui-dialog {
+    padding: 0;
+    border-color: #000000;
+}
+body .ui-dialog .ui-dialog-titlebar {
+    padding: .3em .5em;
+    border: none;
+    border-bottom: 1px solid #000000;
+}
+body .ui-dialog .ui-dialog-titlebar button {
+    border: 1px solid #999999;
+}
+body .ui-dialog .ui-dialog-content {
+    padding: .2em .4em;
+}
+body .ui-dialog .ui-dialog-buttonpane {
+    background: #D3DCE3;
+    border-top: 1px solid #000000;
+}
+body .ui-dialog .ui-dialog-buttonpane button {
+    margin: .1em 0 .1em .4em;
+    border: 1px solid #999999;
+    color: #000000;
+}
+body .ui-dialog .ui-button-text-only .ui-button-text {
+    padding: .2em .6em;
+}
