@@ -20,7 +20,7 @@ if (! PMA_isValid($_REQUEST['url'])
     || ! preg_match('/^https?:\/\/[^\n\r]*$/', $_REQUEST['url'])
     || ! PMA_isAllowedDomain($_REQUEST['url'])
 ) {
-    header('Location: ' . $cfg['PmaAbsoluteUri']);
+    header('Location: ./');
 } else {
     // JavaScript redirection is necessary. Because if header() is used
     //  then web browser sometimes does not change the HTTP_REFERER
@@ -28,7 +28,7 @@ if (! PMA_isValid($_REQUEST['url'])
     //  external site.
     echo "<script type='text/javascript'>
             window.onload=function(){
-                window.location='" . PMA_escapeJsString($_REQUEST['url']) . "';
+                window.location='" , PMA_escapeJsString($_REQUEST['url']) , "';
             }
         </script>";
     // Display redirecting msg on screen.
